@@ -19,6 +19,7 @@
  */
 
 #include <glom/box_reports.h>
+#include <glom/application.h>
 #include <libglom/utils.h> //For bold_message()).
 #include <gtkmm/alignment.h>
 #include <gtkmm/dialog.h>
@@ -64,7 +65,7 @@ void Box_Reports::fill_row(const Gtk::TreeModel::iterator& iter, const sharedptr
     const Glib::ustring report_name = report->get_name();
     m_AddDel.set_value_key(iter, report_name);
     m_AddDel.set_value(iter, m_colReportName, report_name);
-    m_AddDel.set_value(iter, m_colTitle, report->get_title());
+    m_AddDel.set_value(iter, m_colTitle, item_get_title(report));
   }
 }
 
@@ -140,7 +141,7 @@ void Box_Reports::on_adddel_Add(const Gtk::TreeModel::iterator& row)
       m_AddDel.set_value(row, m_colTitle, title);
     }
 
-    report->set_title(title);
+    report->set_title(title, Application::get_current_locale());
 
     get_document()->set_report(m_table_name, report);
   }
@@ -188,7 +189,7 @@ void Box_Reports::save_to_document()
         sharedptr<Report> report(new Report());
         report->set_name(report_name);
 
-        report->set_title( m_AddDel.get_value(iter, m_colTitle) ); //TODO: Translations: Store the original in the TreeView.
+        report->set_title( m_AddDel.get_value(iter, m_colTitle) , Application::get_current_locale()); //TODO: Translations: Store the original in the TreeView.
 
         get_document()->set_report(m_table_name, report);
         modified = true;
@@ -213,7 +214,7 @@ void Box_Reports::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint c
     {
       if(column == m_colTitle)
       {
-        report->set_title( m_AddDel.get_value(row, m_colTitle) );
+        report->set_title( m_AddDel.get_value(row, m_colTitle) , Application::get_current_locale());
         //TODO: Unnecessary:
         document->set_report(m_table_name, report);
       }
